@@ -478,11 +478,8 @@ class SlaveView(gobject.GObject):
 
         self._broker = brokerclass(self, controller)
 
-#    def _setup_keypress_handler(self, keypress_handler):
-#        # Only useful in BaseView and derived classes
-#        # XXX: support slaveview correctly
-#        log.warn("Tried to setup a keypress handler for %s "
-#              "but no toplevel window exists to attach to" % self)
+        if self.toplevel:
+            self.toplevel.connect("key-press-event", controller.on_key_press)
 
     #
     # Slave handling
@@ -531,6 +528,7 @@ class SlaveView(gobject.GObject):
             new_widget = shell
 
         placeholder = self.get_widget(name)
+        placeholder.set_data('kiwi::slave', self)
 
         if not placeholder:
             raise AttributeError(
